
pymssql - DB-API interface to Microsoft SQL Server
==================================================

Feature:
    1. Fine-grained number types, such as int, long, float, double
    2. Cursor description has richer information, such as precision, scale

A simple database interface for `Python`_ that builds on top of `FreeTDS`_ to
provide a Python DB-API (`PEP-249`_) interface to `Microsoft SQL Server`_.

.. _Microsoft SQL Server: http://www.microsoft.com/sqlserver/
.. _Python: http://www.python.org/
.. _PEP-249: http://www.python.org/dev/peps/pep-0249/
.. _FreeTDS: http://www.freetds.org/

